package serverHTTP;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/*
 * La classe Request modella una richiesta HTTP. Mette a disposizione dei metodi per accedere alle informazioni relative all'header e agli elementi della riga di intestazione, quali metodo di accesso
 * alla risorsa, URL e alla verisone di HTTP.
 */
public class Request {
	
	private String accessMethod;
	private String url;
	private String protocol;
	private Map<String,List<String>> header;
	private boolean isValid;
	
	
	/*
	 * Il costruttore analisi la riga di intestazione e l'header
	 */
	public Request(InputStream is){
		List<String> accessMethods = Arrays.asList("GET"); //Lista dei metodi di accesso riconosciuti
		BufferedReader br = new BufferedReader(new InputStreamReader(is));
		try{
			String primaRiga = br.readLine(); //riga di intestazione
			String[] elements = primaRiga.split(" "); //prendo i tre elementi della riga di intestazione
			if(elements.length == 3){ //se non sono tre c'e' un errore
				if(accessMethods.contains(elements[0].toUpperCase()) && (elements[2].equalsIgnoreCase("http/1.0") || elements[2].equalsIgnoreCase("http/1.1"))){ //controllo se metodo e protocollo sono corretti
					header = new HashMap<String,List<String>>();
 					isValid = true;
					accessMethod = elements[0].toUpperCase(); url = elements[1]; protocol = elements[2].toUpperCase(); //campi della riga di intestazione
					String lineaHeader = ""; 
					//Analisi dell'header
					while(!(lineaHeader = br.readLine()).equals("")){
						String[] headerElements = lineaHeader.split("\\:");
						if(headerElements.length == 2){
							String[] value = headerElements[1].trim().split(",");
							ArrayList<String> listValue = new ArrayList<>();
							for (int i = 0; i < value.length; i++) {
								listValue.add(value[i].trim());
							}
							header.put(headerElements[0].trim(), listValue);
						}
					}
				}
				else{
					isValid = false;
				}
			}else{
				isValid = false;
			}
		}catch(IOException ioe){
			System.out.println("Errore nella lettura da socket");
		}
	}

	public String getAccessMethod() {
		return accessMethod;
	}

	/*
	 * Stringa che contiene url della risorsa. Non viene fatta nessuna analisi sintattica, pu essere una qualsiasi stringa
	 */
	public String getUrl() {
		return url;
	}

	public String getProtocol() {
		return protocol;
	}

	public boolean isValid() {
		return isValid;
	}

	/*
	 * L'insieme delle chiavi della mappa restituita sono le chiavi dell'header HTTP, mentre i valori associati sono modellati mediante una lista di stringhe.
	 */
	public Map<String, List<String>> getHeader() {
		return header;
	}	
	
	
}
