package facebook;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;

import javax.net.ssl.HttpsURLConnection;

import org.json.simple.JSONArray;
import org.json.simple.JSONObject;
import org.json.simple.parser.JSONParser;
import org.json.simple.parser.ParseException;


/*
 * In questo esercizio invio una richiesta HTTPS alle Facebook Graph API, anzich utilizzare Graph API explorer. La porzione di codice di 
 * estrazione dell'informazione  analoga a quella proposta nella classe InformazioniMie. 
 * La creazione di una richiesta HTTPS segue quella di una connessione HTTP:
 * 1. Creo url corrispondente alla risorsa, nel nostro caso sar una richiesta a Graph API
 * 2. Invoco metodo openConnection e casto il risultato a HttpsURLConnection
 * 3. Modifico l'header della richiesta con una serie di invocazioni al metodo addRequestProperty
 * 4. Eseguo la connessione con connect() o con getInputStream()
 */
public class RichiestaFacebook {
	
	public static void main(String[] args) {
		String id = args[0]; //ID dell'oggetto Facebook
		String access_token = args[1]; //Access_token prelevato da Graph API Explorer
		String richiesta = "https://graph.facebook.com/"+id+"?access_token="+access_token; //Richiesta API Facebook
		System.out.println(richiesta);
		try {
			URL u = new URL(richiesta);
			HttpsURLConnection connessione = (HttpsURLConnection) u.openConnection(); //Setting della richiesta HTTPS
			//Inserimento dei campi nell'header HTTPS
			connessione.addRequestProperty("user-agent", "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.57 Safari/537.36");
			connessione.addRequestProperty("Origin", "https://developers.facebook.com");
			//Connessione alla risorsa indicata dall'oggetto URL u utilizzando il protocollo HTTPS
			BufferedReader br = new BufferedReader(new InputStreamReader(connessione.getInputStream()));
			JSONParser parser = new JSONParser(); //Inizializzazione del parser
			JSONObject risposta = (JSONObject) parser.parse(br); //parso lo stream. La risposta data da Facebook Graph API  un oggetto JSON
			System.out.println(risposta.get("gender")); //Accedo al campo indicato dalla chiave gender
			JSONArray scuole = (JSONArray) risposta.get("education"); //Accedo al campo indicato dalla chiave education. Il valore  un array JSON
			System.out.println("Numero di elementi nel campo education: "
					+ scuole.size());
			for(Object o:scuole){ //Itero su ogni elemento contenuto nell'array JSON
				JSONObject scuola = (JSONObject) o; //Ogni elemento  un oggetto JSON
				System.out.println("\t"+scuola.get("type")); //Accedo al campo type di ogni elemento
			}
		} catch (MalformedURLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch(IOException ioe){
			ioe.printStackTrace();
		} catch(ParseException pe){
			pe.printStackTrace();
		}
	}

}
