package xmlJson;

import java.io.File;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.w3c.dom.Document;
import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
   
/**
 * Validate XML document specified via DTD using DOM Parser
 */
public class DOMDTDValidation {
   public static void main(String args[]) {
      try {
         DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
         // Abilito la validazione
         factory.setValidating(true);
         DocumentBuilder builder = factory.newDocumentBuilder();
   
         builder.setErrorHandler(new ErrorHandler() {  // anonymous inner class
            //Ignora errori fatali
            @Override
            public void fatalError(SAXParseException exception) throws SAXException {}
   
            // Errori di validazione
            @Override
            public void error(SAXParseException e) throws SAXParseException {
               System.out.print("Errore alla linea " + e.getLineNumber() + ": ");
               System.out.println(e.getMessage());
            }
   
            // Riporto i warning
            @Override
            public void warning(SAXParseException e) throws SAXParseException {
               System.out.print("Warning at line " + e.getLineNumber() + ": ");
               System.out.println(e.getMessage());
            }
         });
   
         // Validazione con DTD esterno
         Document xmlDocument = builder.parse(new File("bookstore.xml"));
         DOMSource source = new DOMSource(xmlDocument);
         StreamResult result = new StreamResult(System.out);
         TransformerFactory transformerFactory = TransformerFactory.newInstance();
         Transformer transformer = transformerFactory.newTransformer();
         transformer.setOutputProperty(OutputKeys.DOCTYPE_SYSTEM, "bookstore.dtd");
         transformer.transform(source, result);
   
         // IValidazione con DTD interno  a xml
         xmlDocument = builder.parse(new File("bookstore-inlineDTD.xml"));
         source = new DOMSource(xmlDocument);
         result = new StreamResult(System.out);
         transformer.transform(source, result);
      } catch (Exception e) {
         e.printStackTrace();
      }
   }
}